lilypondfiletools.LayoutBlock
=============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock

.. autoclass:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.append
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.context_blocks
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.contexts
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.count
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.extend
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.index
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.insert
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.pop
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.remove
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.reverse
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.sort
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__add__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__contains__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__delitem__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__delslice__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__eq__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__format__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__ge__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__getitem__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__getslice__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__gt__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__iadd__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__imul__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__iter__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__le__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__len__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__lt__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__mul__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__ne__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__repr__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__reversed__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__rmul__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__setitem__
      ~abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.AttributedBlock <abjad.tools.lilypondfiletools.AttributedBlock.AttributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.context_blocks
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.contexts
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.LayoutBlock.LayoutBlock.__setslice__
   :noindex:
